@@ -1,8 +1,10 @@
 
 import ctypes
 import sys
+sys.path.append('..')
+print(sys.path)
 from ctypes import *
-from algorithmLib.formatConvert.wav_pcm import get_data_array
+from formatConvert.wav_pcm import get_data_array
 
 def resample(infile,target_amplerate):
     data,fs = get_data_array(infile)
